@@ -1,17 +1,8 @@
 
-/***************************************************************************
-   copyright            : (C) 2006 by David Nolden
-   email                : david.nolden.kdevelop@art-master.de
-***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2006 David Nolden <david.nolden.kdevelop@art-master.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef CACHEMANAGER_H
 #define CACHEMANAGER_H
@@ -29,7 +20,7 @@ class CacheNode
 {
     typedef CacheManager Manager;
 public:
-    CacheNode(Manager* manager);
+    explicit CacheNode(Manager* manager);
 
     virtual ~CacheNode();
 
@@ -75,7 +66,7 @@ public:
     CacheManager(int maxNodes = 1000) : m_currentFrame(1), m_maxNodes(maxNodes), m_currentMax(1)
     {
     };
-    virtual ~CacheManager() {};
+    virtual ~CacheManager() {}
 
     inline int currentFrame() const
     {
