@@ -2,7 +2,7 @@
     Based on kdevelop-3.0 languages/cpp/store_walker.cpp by Roberto Raggi
 
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2004-2014 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2004-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 // own header
@@ -14,6 +14,7 @@
 #include "umllistview.h"
 #include "datatype.h"
 #include "operation.h"
+#define DBG_SRC QStringLiteral("CppTree2Uml")
 #include "debug_utils.h"
 #include "ast_utils.h"
 #include "codeimpthread.h"
@@ -32,6 +33,8 @@
 #include <QList>
 #include <QRegExp>
 
+DEBUG_REGISTER(CppTree2Uml)
+
 CppTree2Uml::CppTree2Uml(const QString& fileName, CodeImpThread* thread)
   : m_thread(thread),
     m_rootFolder(0),
@@ -88,7 +91,7 @@ void CppTree2Uml::parseTranslationUnit(const ParsedFile &file)
         UMLFolder *parent = m_rootFolder;
         QString path;
         if (!m_rootPath.isEmpty())
-            path = fi.path().replace(m_rootPath + QLatin1String("/"), QLatin1String(""));
+            path = fi.path().replace(m_rootPath + QStringLiteral("/"), QStringLiteral(""));
         else
             path = fi.absolutePath();
         if (!path.isEmpty())
@@ -103,7 +106,7 @@ void CppTree2Uml::parseTranslationUnit(const ParsedFile &file)
 void CppTree2Uml::parseNamespace(NamespaceAST* ast)
 {
     if (m_clsCnt > 0) {
-        uDebug() << "error - cannot nest namespace inside class";
+        logDebug0("CppTree2Uml::parseNamespace error - cannot nest namespace inside class");
         return;
     }
 
@@ -116,14 +119,14 @@ void CppTree2Uml::parseNamespace(NamespaceAST* ast)
     } else {
         nsName = ast->namespaceName()->text();
     }
-    uDebug() << nsName;
+    logDebug1("CppTree2Uml::parseNamespace %1", nsName);
     if (m_thread) {
-        m_thread->emitMessageToLog(QString(), QLatin1String("namespace ") + nsName);
+        m_thread->emitMessageToLog(QString(), QStringLiteral("namespace ") + nsName);
     }
     UMLObject *o = m_doc->findUMLObject(nsName, UMLObject::ot_Package, m_currentNamespace[m_nsCnt]);
     if (!o)
         o = m_doc->findUMLObject(nsName, UMLObject::ot_Class, m_currentNamespace[m_nsCnt]);
-    if (o && o->stereotype() == QLatin1String("class-or-package")) {
+    if (o && o->stereotype() == QStringLiteral("class-or-package")) {
         o->setStereotype(QString());
         o->setBaseType(UMLObject::ot_Package);
     }
@@ -135,7 +138,7 @@ void CppTree2Uml::parseNamespace(NamespaceAST* ast)
     UMLPackage *ns = (UMLPackage *)o;
     m_currentScope.push_back(nsName);
     if (++m_nsCnt > STACKSIZE) {
-        uError() << "excessive namespace nesting";
+        logError0("CppTree2Uml::parseNamespace: excessive namespace nesting");
         m_nsCnt = STACKSIZE;
     }
     m_currentNamespace[m_nsCnt] = ns;
@@ -201,13 +204,13 @@ void CppTree2Uml::parseTypedef(TypedefAST* ast)
                     dt->setOriginType(inner->asUMLClassifier());
                 }
                 else {
-                    uError() << "Could not create datatype from" << id;
+                    logError1("CppTree2Uml::parseTypedef: Could not create datatype from id %1", id);
                 }
             } else {
                 Import_Utils::createUMLObject(UMLObject::ot_Class, id,
                                                m_currentNamespace[m_nsCnt],
                                                QString() /* doc */,
-                                               QLatin1String("typedef") /* stereotype */);
+                                               QStringLiteral("typedef") /* stereotype */);
             }
         }
 
@@ -231,7 +234,7 @@ void CppTree2Uml::parseTemplateDeclaration(TemplateDeclarationAST* ast)
                 Model_Utils::NameAndType nt(typeName, 0);
                 m_templateParams.append(nt);
             } else {
-                uError() << "nameNode is NULL";
+                logError0("CppTree2Uml::parseTemplateDeclaration: nameNode is NULL");
             }
         }
 
@@ -239,7 +242,7 @@ void CppTree2Uml::parseTemplateDeclaration(TemplateDeclarationAST* ast)
         if (valueNode) {
             TypeSpecifierAST* typeSpec = valueNode->typeSpec();
             if (typeSpec == 0) {
-                uError() << "typeSpec is NULL";
+                logError0("CppTree2Uml::parseTemplateDeclaration: typeSpec is NULL");
                 continue;
             }
             QString typeName = typeSpec->name()->text();
@@ -248,8 +251,7 @@ void CppTree2Uml::parseTemplateDeclaration(TemplateDeclarationAST* ast)
             DeclaratorAST* declNode = valueNode->declarator();
             NameAST* nameNode = declNode->declaratorId();
             if (nameNode == 0) {
-                uError() << "CppTree2Uml::parseTemplateDeclaration(value):"
-                         << " nameNode is NULL";
+                logError0("CppTree2Uml::parseTemplateDeclaration(value): nameNode is NULL");
                 continue;
             }
             QString paramName = nameNode->unqualifiedName()->text();
@@ -268,7 +270,7 @@ void CppTree2Uml::parseSimpleDeclaration(SimpleDeclarationAST* ast)
     InitDeclaratorListAST* declarators = ast->initDeclaratorList();
     GroupAST* storageSpec = ast->storageSpecifier();
 
-    if (storageSpec && storageSpec->text() == QLatin1String("friend"))
+    if (storageSpec && storageSpec->text() == QStringLiteral("friend"))
         return;
 
     m_comment = ast->comment();
@@ -307,51 +309,55 @@ void CppTree2Uml::parseFunctionDefinition(FunctionDefinitionAST* ast)
     bool isExplicit = false;
     bool isConstExpression = false;
 
-    if (funSpec){
+    if (funSpec) {
         QList<AST*> l = funSpec->nodeList();
         for (int i = 0; i < l.size(); ++i) {
             QString text = l.at(i)->text();
-            if (text == QLatin1String("virtual"))
+            if (text == QStringLiteral("virtual"))
                 isVirtual = true;
-            else if (text == QLatin1String("inline"))
+            else if (text == QStringLiteral("inline"))
                 isInline = true;
-            else if (text == QLatin1String("explicit"))
+            else if (text == QStringLiteral("explicit"))
                 isExplicit = true;
         }
     }
 
-    if (storageSpec){
+    if (storageSpec) {
         QList<AST*> l = storageSpec->nodeList();
         for (int i = 0; i < l.size(); ++i) {
             QString text = l.at(i)->text();
-            if (text == QLatin1String("friend")) isFriend = true;
-            else if (text == QLatin1String("static")) isStatic = true;
-            else if (text == QLatin1String("constexpr"))
+            if (text == QStringLiteral("friend"))
+                isFriend = true;
+            else if (text == QStringLiteral("static"))
+                isStatic = true;
+            else if (text == QStringLiteral("constexpr"))
                 isConstExpression = true;
         }
     }
 
     QString id = d->declaratorId()->unqualifiedName()->text().trimmed();
     if (m_thread) {
-        m_thread->emitMessageToLog(QString(), QLatin1String("method ") + id);
+        m_thread->emitMessageToLog(QString(), QStringLiteral("method ") + id);
     }
-    uDebug() << id;
+    logDebug1("CppTree2Uml::parseFunctionDefinition %1", id);
 
     UMLClassifier *c = m_currentClass[m_clsCnt];
     if (c == 0) {
-        uDebug() << id << ": need a surrounding class.";
+        logDebug1("CppTree2Uml::parseFunctionDefinition %1: need a surrounding class.", id);
         return;
     }
 
     QString returnType = typeOfDeclaration(typeSpec, d);
     UMLOperation *m = Import_Utils::makeOperation(c, id);
     if (isConstExpression)
-        m->setStereotype(QLatin1String("constexpr"));
+        m->setStereotype(QStringLiteral("constexpr"));
     if (isVirtual)
         m->setVirtual(true);
     if (isInline)
         m->setInline(true);
-    if (d->override())
+    if (d->final_())
+        m->setFinal(true);
+    if (d->override_())
         m->setOverride(true);
     if (d->constant())
         m->setConst(true);
@@ -372,13 +378,13 @@ void CppTree2Uml::parseFunctionDefinition(FunctionDefinitionAST* ast)
     if  (isConstructor) {
         QString stereotype;
         if (isExplicit)
-            stereotype.append(QLatin1String("explicit "));
+            stereotype.append(QStringLiteral("explicit "));
         if (isConstExpression)
-            stereotype.append(QLatin1String("constexpr "));
-        stereotype.append(QLatin1String("constructor"));
+            stereotype.append(QStringLiteral("constexpr "));
+        stereotype.append(QStringLiteral("constructor"));
         m->setStereotype(stereotype);
     } else if (isConstExpression)
-        m->setStereotype(QLatin1String("constexpr"));
+        m->setStereotype(QStringLiteral("constexpr"));
 
 /* For reference, Kdevelop does some more:
     method->setFileName(m_fileName);
@@ -410,35 +416,35 @@ void CppTree2Uml::parseClassSpecifier(ClassSpecifierAST* ast)
     } else {
         className = ast->name()->unqualifiedName()->text().trimmed();
     }
-    uDebug() << "name=" << className;
+    logDebug1("CppTree2Uml::parseClassSpecifier name=%1", className);
     if (m_thread) {
-        m_thread->emitMessageToLog(QString(), QLatin1String("class ") + className);
+        m_thread->emitMessageToLog(QString(), QStringLiteral("class ") + className);
     }
     QStringList scope = scopeOfName(ast->name(), QStringList());
     UMLObject *localParent = 0;
     if (!scope.isEmpty()) {
-        localParent = m_doc->findUMLObject(scope.join(QLatin1String("::")),
+        localParent = m_doc->findUMLObject(scope.join(QStringLiteral("::")),
                                            UMLObject::ot_Class, m_currentNamespace[m_nsCnt]);
         if (!localParent)
-            localParent = m_doc->findUMLObject(scope.join(QLatin1String("::")),
+            localParent = m_doc->findUMLObject(scope.join(QStringLiteral("::")),
                                                UMLObject::ot_Package, m_currentNamespace[m_nsCnt]);
         if (!localParent) {
             localParent = Import_Utils::createUMLObject(UMLObject::ot_Class, className,
                                                         m_currentNamespace[m_nsCnt],
                                                         ast->comment(), QString(), true);
-            localParent->setStereotype(QLatin1String("class-or-package"));
+            localParent->setStereotype(QStringLiteral("class-or-package"));
         }
         m_currentNamespace[++m_nsCnt] = localParent->asUMLPackage();
     }
 
     if (className.isEmpty()) {
-        className = QLatin1String("anon_") + QString::number(m_anon);
+        className = QStringLiteral("anon_") + QString::number(m_anon);
         m_anon++;
     }
     UMLObject *o = m_doc->findUMLObject(className, UMLObject::ot_Class, m_currentNamespace[m_nsCnt]);
     if (!o)
         o = m_doc->findUMLObject(className, UMLObject::ot_Datatype, m_currentNamespace[m_nsCnt]);
-    if (o && o->stereotype() == QLatin1String("class-or-package")) {
+    if (o && o->stereotype() == QStringLiteral("class-or-package")) {
         o->setStereotype(QString());
         o->setBaseType(UMLObject::ot_Class);
     }
@@ -455,12 +461,12 @@ void CppTree2Uml::parseClassSpecifier(ClassSpecifierAST* ast)
 
     m_currentScope.push_back(className);
     if (++m_clsCnt > STACKSIZE) {
-        uError() << "excessive class nesting";
+        logError0("CppTree2Uml::parseClassSpecifier: excessive class nesting");
         m_clsCnt = STACKSIZE;
     }
     m_currentClass[m_clsCnt] = klass;
     if (++m_nsCnt > STACKSIZE) {
-        uError() << "excessive namespace nesting";
+        logError0("CppTree2Uml::parseClassSpecifier: excessive namespace nesting");
         m_nsCnt = STACKSIZE;
     }
     m_currentNamespace[m_nsCnt] = (UMLPackage*)klass;
@@ -472,7 +478,7 @@ void CppTree2Uml::parseClassSpecifier(ClassSpecifierAST* ast)
 
     m_currentScope.pop_back();
 
-    // check is class is an interface
+    // check if class is an interface
     bool isInterface = true;
     foreach(UMLOperation *op, klass->getOpList()) {
         if (!op->isDestructorOperation() && op->isAbstract() == false)
@@ -480,7 +486,7 @@ void CppTree2Uml::parseClassSpecifier(ClassSpecifierAST* ast)
     }
 
     foreach(UMLAttribute *attr, klass->getAttributeList()) {
-        if (!(attr->isStatic() && attr->getTypeName().contains(QLatin1String("const"))))
+        if (!(attr->isStatic() && attr->getTypeName().contains(QStringLiteral("const"))))
             isInterface = false;
     }
 
@@ -524,24 +530,12 @@ void CppTree2Uml::parseElaboratedTypeSpecifier(ElaboratedTypeSpecifierAST* typeS
     ///              - Using typeSpec->text() is probably not good, decode
     ///                the kind() instead.
     QString text = typeSpec->text();
-    uDebug() << "forward declaration of " << text;
+    logDebug1("CppTree2Uml::parseElaboratedTypeSpecifier forward declaration of %1", text);
     if (m_thread) {
-        m_thread->emitMessageToLog(QString(), QLatin1String("forward declaration of ") + text);
+        m_thread->emitMessageToLog(QString(), QStringLiteral("forward declaration of ") + text);
     }
-    text.remove(QRegExp(QLatin1String("^class\\s+")));
-#if 0
-    if (m_thread) {  //:TODO: for testing only
-        int answer;
-        m_thread->emitAskQuestion("Soll CppTree2Uml::parseElaboratedTypeSpecifier ausgeführt werden?");
-        uDebug() << "Antwort: " << answer;
-    }
-#endif
+    text.remove(QRegExp(QStringLiteral("^class\\s+")));
     UMLObject *o = Import_Utils::createUMLObject(UMLObject::ot_Class, text, m_currentNamespace[m_nsCnt]);
-#if 0
-    if (m_thread) {  //:TODO: for testing only
-        m_thread->emitAskQuestion("Soll nach CppTree2Uml::parseElaboratedTypeSpecifier weiter gemacht werden?");
-    }
-#endif
     flushTemplateParams(o->asUMLClassifier());
 }
 
@@ -568,13 +562,13 @@ void CppTree2Uml::parseDeclaration2(GroupAST* funSpec, GroupAST* storageSpec,
         id = t->declaratorId()->unqualifiedName()->text();
 
     if (!scopeOfDeclarator(d, QStringList()).isEmpty()){
-        uDebug() << id << ": skipping.";
+        logDebug1("CppTree2Uml::parseDeclaration2 %1: skipping.", id);
         return;
     }
 
     UMLClassifier *c = m_currentClass[m_clsCnt];
     if (c == 0) {
-        uDebug() << id << ": need a surrounding class.";
+        logDebug1("CppTree2Uml::parseDeclaration2 %1: need a surrounding class.", id);
         return;
     }
 
@@ -587,18 +581,18 @@ void CppTree2Uml::parseDeclaration2(GroupAST* funSpec, GroupAST* storageSpec,
         QList<AST*> l = storageSpec->nodeList();
         for (int i = 0; i < l.size(); ++i) {
             QString text = l.at(i)->text();
-            if (text == QLatin1String("static"))
+            if (text == QStringLiteral("static"))
                 isStatic = true;
-            else if (text == QLatin1String("mutable"))
-                typeName.prepend(text + QLatin1String(" "));
-            else if (text == QLatin1String("friend"))
+            else if (text == QStringLiteral("mutable"))
+                typeName.prepend(text + QStringLiteral(" "));
+            else if (text == QStringLiteral("friend"))
                 isFriend = true;
         }
     }
 
     UMLAttribute *attribute = Import_Utils::insertAttribute(c, m_currentAccess, id, typeName, m_comment, isStatic);
     if (isFriend)
-        attribute->setStereotype(QLatin1String("friend"));
+        attribute->setStereotype(QStringLiteral("friend"));
     m_comment = QString();
 }
 
@@ -610,8 +604,8 @@ void CppTree2Uml::parseAccessDeclaration(AccessDeclarationAST * access)
 
     m_currentAccess=Uml::Visibility::fromString(accessStr);
 
-    m_inSlots = l.count() > 1 ? l.at(1)->text() == QLatin1String("slots") : false;
-    m_inSignals = l.count() >= 1 ? l.at(0)->text() == QLatin1String("signals") : false;
+    m_inSlots = l.count() > 1 ? l.at(1)->text() == QStringLiteral("slots") : false;
+    m_inSignals = l.count() >= 1 ? l.at(0)->text() == QStringLiteral("signals") : false;
 }
 
 void CppTree2Uml::parseFunctionDeclaration(GroupAST* funSpec, GroupAST* storageSpec,
@@ -631,11 +625,11 @@ void CppTree2Uml::parseFunctionDeclaration(GroupAST* funSpec, GroupAST* storageS
         QList<AST*> l = funSpec->nodeList();
         for (int i = 0; i < l.size(); ++i) {
             QString text = l.at(i)->text();
-            if (text == QLatin1String("virtual"))
+            if (text == QStringLiteral("virtual"))
                 isVirtual = true;
-            else if (text == QLatin1String("inline"))
+            else if (text == QStringLiteral("inline"))
                 isInline = true;
-            else if (text == QLatin1String("explicit"))
+            else if (text == QStringLiteral("explicit"))
                 isExplicit = true;
         }
     }
@@ -644,9 +638,9 @@ void CppTree2Uml::parseFunctionDeclaration(GroupAST* funSpec, GroupAST* storageS
         QList<AST*> l = storageSpec->nodeList();
         for (int i = 0; i < l.size(); ++i) {
             QString text = l.at(i)->text();
-            if (text == QLatin1String("friend")) isFriend = true;
-            else if (text == QLatin1String("static")) isStatic = true;
-            else if (text == QLatin1String("constexpr"))
+            if (text == QStringLiteral("friend")) isFriend = true;
+            else if (text == QStringLiteral("static")) isStatic = true;
+            else if (text == QStringLiteral("constexpr"))
                 isConstExpression = true;
         }
     }
@@ -656,28 +650,29 @@ void CppTree2Uml::parseFunctionDeclaration(GroupAST* funSpec, GroupAST* storageS
 
     UMLClassifier *c = m_currentClass[m_clsCnt];
     if (c == 0) {
-        uDebug() << id << ": need a surrounding class.";
+        logDebug1("CppTree2Uml::parseFunctionDeclaration %1: need a surrounding class.", id);
         return;
     }
 
     QString returnType = typeOfDeclaration(typeSpec, d);
-    // if a class has no return type, it could de a constructor or
-    // a destructor
+    // if a class has no return type it could be a constructor or a destructor
     if (d && returnType.isEmpty()) {
-        if (id.indexOf(QLatin1Char('~')) == -1)
-            isConstructor = true;
-        else {
+        if (id.contains(QLatin1Char('~'))) {
             isDestructor = true;
-            id.remove(QLatin1String(" "));
+            id.remove(QStringLiteral(" "));
+        } else {
+            isConstructor = true;
         }
     }
     UMLOperation *m = Import_Utils::makeOperation(c, id);
-    if (d->override())
+    if (d->final_())
+        m->setFinal(true);
+    if (d->override_())
         m->setOverride(true);
     if (d->constant())
         m->setConst(true);
     if (isConstExpression)
-        m->setStereotype(QLatin1String("constexpr"));
+        m->setStereotype(QStringLiteral("constexpr"));
     if (isVirtual)
         m->setVirtual(true);
     if (isInline)
@@ -692,13 +687,13 @@ void CppTree2Uml::parseFunctionDeclaration(GroupAST* funSpec, GroupAST* storageS
     if  (isConstructor) {
         QString stereotype;
         if (isExplicit)
-            stereotype.append(QLatin1String("explicit "));
+            stereotype.append(QStringLiteral("explicit "));
         if (isConstExpression)
-            stereotype.append(QLatin1String("constexpr "));
-        stereotype.append(QLatin1String("constructor"));
+            stereotype.append(QStringLiteral("constexpr "));
+        stereotype.append(QStringLiteral("constructor"));
         m->setStereotype(stereotype);
     } else if (isConstExpression)
-        m->setStereotype(QLatin1String("constexpr"));
+        m->setStereotype(QStringLiteral("constexpr"));
 
     m_comment = QString();
 }
@@ -722,7 +717,7 @@ void CppTree2Uml::parseFunctionArguments(DeclaratorAST* declarator,
 
             QString tp = typeOfDeclaration(param->typeSpec(), param->declarator());
 
-            if (tp != QLatin1String("void"))
+            if (tp != QStringLiteral("void"))
                 Import_Utils::addMethodParameter(method, tp, name);
         }
     }
@@ -739,12 +734,14 @@ QString CppTree2Uml::typeOfDeclaration(TypeSpecifierAST* typeSpec, DeclaratorAST
 
     QList<AST*> ptrOpList = declarator->ptrOpList();
     for (int i = 0; i < ptrOpList.size(); ++i) {
-        text += ptrOpList.at(i)->text();
+        QString ptr = ptrOpList.at(i)->text();
+        text += ptr.replace(QStringLiteral(" "), QStringLiteral(""));
     }
 
     QList<AST*> arrays = declarator->arrayDimensionList();
     for(int i = 0; i < arrays.size(); ++i) {
-        text += arrays.at(i)->text().replace(QLatin1String(" "), QLatin1String(""));
+        QString dim = arrays.at(i)->text();
+        text += dim.replace(QStringLiteral(" "), QStringLiteral(""));
     }
 
     return text;
@@ -758,12 +755,12 @@ void CppTree2Uml::parseBaseClause(BaseClauseAST * baseClause, UMLClassifier* kla
 
         NameAST *name = baseSpecifier->name();
         if (name == 0) {
-                uDebug() << "baseSpecifier->name() is NULL";
-                continue;
+            logDebug0("CppTree2Uml::parseBaseClause: baseSpecifier->name() is NULL");
+            continue;
         }
         ClassOrNamespaceNameAST *cons = name->unqualifiedName();
         if (cons == 0) {
-            uDebug() << "name->unqualifiedName() is NULL";
+            logDebug0("CppTree2Uml::parseBaseClause: name->unqualifiedName() is NULL");
             continue;
         }
         QString baseName = cons->name()->text();
@@ -807,7 +804,7 @@ void CppTree2Uml::flushTemplateParams(UMLClassifier *klass)
         Model_Utils::NameAndType_ListIt it;
         for (it = m_templateParams.begin(); it != m_templateParams.end(); ++it) {
             const Model_Utils::NameAndType &nt = *it;
-            uDebug() << "adding template param: " << nt.m_name;
+            logDebug1("CppTree2Uml::flushTemplateParams adding template param: %1", nt.m_name);
             UMLTemplate *tmpl = klass->addTemplate(nt.m_name);
             tmpl->setType(nt.m_type);
         }
