@@ -1,15 +1,11 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2002-2021 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2002-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 #ifndef UMBRELLO_VERSION_H
 #define UMBRELLO_VERSION_H
 
-#if QT_VERSION < 0x050000
-#include <kdeversion.h>
-#endif
-
 inline QByteArray umbrelloVersion()
 {
 #ifdef UMBRELLO_VERSION_STRING
@@ -21,12 +17,12 @@ inline QByteArray umbrelloVersion()
         .arg(KDE::versionRelease());
 #endif
 #if defined(ENABLE_WIDGET_SHOW_DOC) || defined(ENABLE_XMIRESOLUTION)
-    versionStr.append(QLatin1String(" (experimental)"));
+    versionStr.append(QStringLiteral(" (experimental)"));
 #endif
 #ifdef APPLICATIONS_VERSION_STRING
-    versionStr.append(QLatin1String(" (Applications "));
+    versionStr.append(QStringLiteral(" (Applications "));
     versionStr.append(QString::fromLatin1(APPLICATIONS_VERSION_STRING));
-    versionStr.append(QLatin1String(")"));
+    versionStr.append(QStringLiteral(")"));
     return versionStr.toLatin1();
 #endif
 }
